
# Slot: name


the 'title' of the publication is generally recorded in the 'name' property (inherited from NamedThing). The field name 'title' is now also tagged as an acceptable alias for the node property 'name' (just in case).

URI: [biolink:publication_name](https://w3id.org/biolink/vocab/publication_name)


## Domain and Range

[Publication](Publication.md) &#8594;  <sub>0..1</sub> [LabelType](types/LabelType.md)

## Parents

 *  is_a: [name](name.md)

## Children


## Used by

 * [Article](Article.md)
 * [Book](Book.md)
 * [BookChapter](BookChapter.md)
 * [Publication](Publication.md)
 * [Serial](Serial.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | label |
|  | | display name |
|  | | title |
| **Mappings:** | | rdfs:label |
| **In Subsets:** | | translator_minimal |
|  | | samples |
| **Exact Mappings:** | | gff3:Name |
|  | | gpi:DB_Object_Name |
| **Narrow Mappings:** | | dct:title |
|  | | WIKIDATA_PROPERTY:P1476 |

